@@ -32,6 +32,7 @@ from mikro.graphql.queries.representation import GET_REPRESENTATION
 from mikro.widgets import MY_TOP_REPRESENTATIONS, MY_TOP_SAMPLES
 
 Representation = ForwardRef("Representation")
+Table = ForwardRef("Table")
 Sample = ForwardRef("Sample")
 Experiment = ForwardRef("Experiment")
 
@@ -42,12 +43,12 @@ class RepresentationVariety(str, Enum):
     UNKNOWN = "UNKNOWN"
 
 
-class RepresentationMetric(GraphQLModel):
+class Metric(GraphQLModel):
     key: Optional[str]
     value: Optional[Any]
 
     class Meta:
-        identifier = "representationmetric"
+        identifier = "metric"
         ward = "mikro"
         create = CREATE_METRIC
 
@@ -151,7 +152,8 @@ class Representation(GraphQLModel, Array):
     variety: Optional[RepresentationVariety]
     sample: Optional[Sample]
     tags: Optional[List[str]]
-    metrics: Optional[List[RepresentationMetric]]
+    tables: Optional[List[Table]]
+    metrics: Optional[List[Metric]]
     thumbnail: Optional[str]
 
     asyncs = AsyncRepresentationManager()
@@ -204,5 +206,6 @@ class Table(GraphQLModel, Parquet):
 
 
 Representation.update_forward_refs()
+Table.update_forward_refs()
 Sample.update_forward_refs()
 Experiment.update_forward_refs()
